==> zope.app.apidoc_3.7.5.orig.tar.gz: zope.app.apidoc-3.7.5/src/zope/app/apidoc/bookmodule/metadirectives.py <==
##############################################################################
#
# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Schema for the ``apidoc:bookchapter`` directive

$Id: metadirectives.py 113308 2010-06-10 01:09:36Z srichter $
"""
__docformat__ = 'restructuredtext'

from zope.configuration.fields import Path, MessageID, Tokens
from zope.interface import Interface
from zope.schema import BytesLine, TextLine

class IBookChapterDirective(Interface):
    """Register a new Book Chapter"""

    id = BytesLine(
        title=u"Topic Id",
        description=u"Id of the chapter as it will appear in the URL.",
        required=True)

    title = MessageID(
        title=u"Title",
        description=u"Provides a title for the chapter.",
        required=True)

    doc_path = Path(
        title=u"Path to File",
        description=u"Path to the file that contains the chapter content.",
        required=False)

    parent = BytesLine(
        title=u"Parent Chapter",
        description=u"Id of the parent chapter.",
        default="",
        required=False)

    resources = Tokens(
        title=u"A list of resources.",
        description=u"""
        A list of resources which shall be user for the chapter. The
        resources must be located in the same directory as the chapter.
        """,
        value_type=TextLine(),
        required=False
        )

==> zope.app.apidoc-4.3.0.tar.gz: zope.app.apidoc-4.3.0/src/zope/app/apidoc/bookmodule/metadirectives.py <==
##############################################################################
#
# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Schema for the ``apidoc:bookchapter`` directive

"""
__docformat__ = 'restructuredtext'

from zope.configuration.fields import Path, MessageID, Tokens
from zope.interface import Interface
from zope.schema import NativeStringLine, TextLine


class IBookChapterDirective(Interface):
    """Register a new Book Chapter"""

    id = NativeStringLine(
        title=u"Topic Id",
        description=u"Id of the chapter as it will appear in the URL.",
        required=True)

    title = MessageID(
        title=u"Title",
        description=u"Provides a title for the chapter.",
        required=True)

    doc_path = Path(
        title=u"Path to File",
        description=u"Path to the file that contains the chapter content.",
        required=False)

    parent = NativeStringLine(
        title=u"Parent Chapter",
        description=u"Id of the parent chapter.",
        default="",
        required=False)

    resources = Tokens(
        title=u"A list of resources.",
        description=u"""
        A list of resources which shall be user for the chapter. The
        resources must be located in the same directory as the chapter.
        """,
        value_type=TextLine(),
        required=False
    )
